@@ -228,7 +228,8 @@ def AddCreateInstanceFlags(parser):
       'NVIDIA_TESLA_V100', 'NVIDIA_TESLA_P4', 'NVIDIA_TESLA_T4',
       'NVIDIA_TESLA_A100', 'NVIDIA_A100_80GB',
       'NVIDIA_TESLA_T4_VWS', 'NVIDIA_TESLA_P100_VWS', 'NVIDIA_TESLA_P4_VWS',
-      'NVIDIA_L4', 'NVIDIA_H100_80GB', 'NVIDIA_H100_MEGA_80GB'
+      'NVIDIA_L4', 'NVIDIA_H100_80GB', 'NVIDIA_H100_MEGA_80GB',
+      'NVIDIA_H200_141GB', 'NVIDIA_B200'
   ]
   disk_choices = ['PD_STANDARD', 'PD_SSD', 'PD_BALANCED', 'PD_EXTREME']
   encryption_choices = ['GMEK', 'CMEK']
@@ -655,7 +656,8 @@ def AddUpdateInstanceFlags(parser):
       'NVIDIA_TESLA_V100', 'NVIDIA_TESLA_P4', 'NVIDIA_TESLA_T4',
       'NVIDIA_TESLA_A100', 'NVIDIA_A100_80GB',
       'NVIDIA_TESLA_T4_VWS', 'NVIDIA_TESLA_P100_VWS', 'NVIDIA_TESLA_P4_VWS',
-      'NVIDIA_L4', 'NVIDIA_H100_80GB', 'NVIDIA_H100_MEGA_80GB'
+      'NVIDIA_L4', 'NVIDIA_H100_80GB', 'NVIDIA_H100_MEGA_80GB',
+      'NVIDIA_H200_141GB', 'NVIDIA_B200'
   ]
   AddInstanceResource(parser)
   gce_setup_group = parser.add_group(
@@ -677,7 +679,7 @@ def AddUpdateInstanceFlags(parser):
   gpu_group.add_argument(
       '--install-gpu-driver',
       help='Install gpu driver',
-      type=bool)
+      action='store_true',)
   gpu_group.add_argument(
       '--custom-gpu-driver-path',
       help='custom gpu driver path',
