@@ -25,6 +25,7 @@ from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.compute import metadata_utils
 from googlecloudsdk.api_lib.compute import utils
 from googlecloudsdk.api_lib.container import api_adapter
+from googlecloudsdk.api_lib.container import constants as api_constants
 from googlecloudsdk.api_lib.container import kubeconfig as kconfig
 from googlecloudsdk.api_lib.container import util
 from googlecloudsdk.api_lib.functions import api_enablement
@@ -241,11 +242,17 @@ def ParseCreateOptionsBase(
       addons = {api_adapter.RAYOPERATOR: True}
     else:
       addons[api_adapter.RAYOPERATOR] = True
+  if getattr(args, 'enable_slurm_operator', None):
+    if addons is None:
+      addons = {api_adapter.SLURMOPERATOR: True}
+    else:
+      addons[api_adapter.SLURMOPERATOR] = True
   if getattr(args, 'enable_lustre_csi_driver', None):
     if addons is None:
       addons = {api_adapter.LUSTRECSIDRIVER: True}
     else:
       addons[api_adapter.LUSTRECSIDRIVER] = True
+  enable_pod_snapshots = get_default('pod_snapshots_enabled')
 
   return api_adapter.CreateClusterOptions(
       accelerators=get_default('accelerator'),
@@ -338,6 +345,12 @@ def ParseCreateOptionsBase(
       labels=get_default('labels'),
       local_nvme_ssd_block=(local_nvme_ssd_block),
       local_ssd_count=get_default('local_ssd_count'),
+      maintenance_minor_version_disruption_interval=get_default(
+          'maintenance_minor_version_disruption_interval'
+          ),
+      maintenance_patch_version_disruption_interval=get_default(
+          'maintenance_patch_version_disruption_interval'
+          ),
       maintenance_window=get_default('maintenance_window'),
       maintenance_window_start=get_default('maintenance_window_start'),
       maintenance_window_end=get_default('maintenance_window_end'),
@@ -503,7 +516,11 @@ def ParseCreateOptionsBase(
           'enable_runtime_vulnerability_insight'
       ),
       workload_policies=get_default('workload_policies'),
+      autopilot_cluster_policies=get_default('autopilot_cluster_policies'),
       in_transit_encryption=get_default('in_transit_encryption'),
+      enable_kernel_module_signature_enforcement=get_default(
+          'enable_kernel_module_signature_enforcement'
+      ),
       containerd_config_from_file=get_default('containerd_config_from_file'),
       fleet_project=get_default('fleet_project'),
       enable_fleet=get_default('enable_fleet'),
@@ -569,6 +586,9 @@ def ParseCreateOptionsBase(
       enable_auto_ipam=get_default('enable_auto_ipam'),
       enable_k8s_tokens_via_dns=get_default('enable_k8s_tokens_via_dns'),
       enable_legacy_lustre_port=get_default('enable_legacy_lustre_port'),
+      disable_multi_nic_lustre=get_default('disable_multi_nic_lustre'),
+      enable_lustre_multi_nic=get_default('enable_lustre_multi_nic'),
+      enable_pod_snapshots=enable_pod_snapshots,
       enable_default_compute_class=get_default('enable_default_compute_class'),
       enable_k8s_certs_via_dns=get_default('enable_k8s_certs_via_dns'),
       boot_disk_provisioned_iops=get_default('boot_disk_provisioned_iops'),
@@ -577,6 +597,8 @@ def ParseCreateOptionsBase(
       ),
       network_tier=get_default('network_tier'),
       control_plane_egress_mode=get_default('control_plane_egress'),
+      enable_slice_controller=get_default('enable_slice_controller'),
+      autopilot_general_profile=get_default('autopilot_general_profile'),
   )
 
 GA = 'ga'
@@ -669,6 +691,9 @@ flags_to_add = {
         'hpaprofile': flags.AddHPAProfilesFlag,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'args': _Args,
         'basicauth': flags.AddBasicAuthFlags,
@@ -717,6 +742,9 @@ flags_to_add = {
         'logging': flags.AddLoggingFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -833,6 +861,10 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
@@ -840,6 +872,13 @@ flags_to_add = {
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
+        'enableKernelModuleSignatureEnforcement': (
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
     BETA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -853,6 +892,9 @@ flags_to_add = {
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'basicauth': flags.AddBasicAuthFlags,
         'binauthz': lambda p: flags.AddBinauthzFlags(
             p, release_track=base.ReleaseTrack.BETA
@@ -907,6 +949,9 @@ flags_to_add = {
         'legacyauth': flags.AddEnableLegacyAuthorizationFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -1040,16 +1085,28 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
-            p, hidden=True
+            p, hidden=False
         ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
+        'podsnapshots': flags.AddPodSnapshotConfigFlags,
+        'enableKernelModuleSignatureEnforcement': (
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1062,6 +1119,9 @@ flags_to_add = {
         'autorepair': AddAutoRepair,
         'autoscalingprofiles': flags.AddAutoscalingProfilesFlag,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'hpaprofile': flags.AddHPAProfilesFlag,
         'basicauth': flags.AddBasicAuthFlags,
         'cloudlogging': flags.AddEnableCloudLogging,
@@ -1129,6 +1189,9 @@ flags_to_add = {
         'maxnodes': flags.AddMaxNodesPerPool,
         'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -1256,16 +1319,28 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
-            p, hidden=True
+            p, hidden=False
         ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
+        'podsnapshots': flags.AddPodSnapshotConfigFlags,
+        'enableKernelModuleSignatureEnforcement': (
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
 }
 # LINT.ThenChange(create_auto.py:auto_flags)
@@ -1359,7 +1434,16 @@ class Create(base.CreateCommand):
           'https://cloud.google.com/kubernetes-engine/docs/how-to/private-clusters'
       )
 
-    if not options.enable_ip_alias and not options.enable_auto_ipam:
+    is_cluster_ipv6 = (
+        options.stack_type
+        and options.stack_type.lower() == api_constants.IPV6_STACK_TYPE
+    )
+
+    if (
+        not options.enable_ip_alias
+        and not options.enable_auto_ipam
+        and not is_cluster_ipv6
+    ):
       max_node_number = util.CalculateMaxNodeNumberByPodRange(
           options.cluster_ipv4_cidr
       )
@@ -1621,6 +1705,7 @@ class CreateBeta(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1784,6 +1869,7 @@ class CreateAlpha(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1791,4 +1877,5 @@ class CreateAlpha(Create):
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
+    ops.autopilot_general_profile = get_default('autopilot_general_profile')
     return ops
